==> haskell-wreq-0.5.4.3-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-3cQBlKGEDvTLEZ879BsRPN
key:                  wreq-0.5.4.3-3cQBlKGEDvTLEZ879BsRPN
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  24ec219929ecc3857b30dbe4ccedaf5d
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-3cQBlKGEDvTLEZ879BsRPN
depends:
    aeson-2.1.2.1-U8Qicry0zF1f9E1tHxOto
    attoparsec-0.14.4-C65PLyhXhiCHiJkC3KuQ9j
    authenticate-oauth-1.7-DKeZRJ1RJs73529PZdc7pM base-4.17.2.1
    base16-bytestring-1.0.2.0-8cYMJjJ2evUJdToLJsrqX6
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2YJdsrn6pUkJFkSDuYKbj5
    containers-0.6.7 crypton-1.0.3-G7s1L5mSgXoGTgE7gcokt6
    exceptions-0.10.5 ghc-prim-0.9.1
    hashable-1.4.5.0-EdCBZmCkEma7WCMhhvMdNf
    http-client-0.7.19-LmgoxlGljmmJ4yfMmVG9tj
    http-client-tls-0.3.6.4-CWf1zUvMsiN34DRbq0lWlt
    http-types-0.12.4-36n5pJIqV0vLBUyZ9LbmPR
    lens-5.3.1-GXFgjSkl7U7Fy6s0hRmBiy
    lens-aeson-1.2.3-4klmh9RAFPL5EgLVeAPSwM
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    psqueues-0.2.8.2-9760Fj73w1U4orPfw8Odzo template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20-KWLixwBKCEK6ORqUSVo2CW

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.4.3-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-J4r6B3kmFF1Bam8yOoZqvi
key:                  wreq-0.5.4.3-J4r6B3kmFF1Bam8yOoZqvi
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  0888137cb7016b1f87ab4eb8f6ea6e32
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-J4r6B3kmFF1Bam8yOoZqvi
depends:
    aeson-2.1.2.1-LvJWrHbVhNW5j5NGQeCpIT
    attoparsec-0.14.4-IxPlyKeM7RE2Q1eOkxwOEV
    authenticate-oauth-1.7-Ia14oaukLMg4AdyVlxHl7R base-4.17.2.1
    base16-bytestring-1.0.2.0-Eyzq7m0xe67GiRftjHundc
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3W7hj1sdmUw2Fh1p1ue6cC
    containers-0.6.7 crypton-1.0.3-7bIVfz7v17tJuJ7xRVIZw4
    exceptions-0.10.5 ghc-prim-0.9.1
    hashable-1.4.5.0-tUQ3ISdCwwAzRS3LRBhXn
    http-client-0.7.19-AatRlGUPnZy5vGSpZr81Ei
    http-client-tls-0.3.6.4-58jh7szMQK37VFPzhWvxnZ
    http-types-0.12.4-Lh5dVrkMNHmKdCH2kircer
    lens-5.3.1-1aYkBqtQBz47fMfVuyOc0c
    lens-aeson-1.2.3-Aaxs90kSZWE69X0KLLFavq
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    psqueues-0.2.8.2-1oOsUU3QlhKBTdLQtittrg template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20-Kt9XOM1GYdv4KClqugAe9a

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
